@@ -1,18 +1,22 @@
 import numpy as np
 import talib as ta
 import pandas as pd
+import numba as nb
+from numba import jit
 from MA import *
 
 
-def BOLL(Series, M, N):
-    a = MA(Series, M)
+# @jit(nopython=True)
+def BOLL(Series, M, N, padding=None):
+    mid = MA(Series, M, padding)
     len_series = len(Series)
     close_series = []
     for i in range(len_series - M + 1):
         close_series.append(Series[i:i + M])
-    upper = a + N * np.std(close_series, M)
-    lower = a - N * np.std(close_series, M)
-    return a, upper, lower
+
+    upper = mid + N * np.std(close_series)
+    lower = mid - N * np.std(close_series)
+    return upper, mid, lower
 
 
 def talib_boll(close, m, n):
